==> artan-react-ui-sample-0.0.31.tgz: package/src/Presentation/components/UI/Dialogs/MessagesView/AIWidgets/UseDefaultAIAssistAnswerWidget.tsx <==
import { useState } from 'react';
import { AIMessageWidget } from './AIMessageWidget';
import AIWidgetIcon from '../../../svgs/Icons/AIWidgets/AIWidget';
import { IChatMessage } from '../../../../../Views/Base/BaseViewModel';
import { stringifyError } from '../../../../../../utils/parse';
import ErrorMessageIcon from './ErrorMessageIcon';

interface MessageWidgetProps {
  // https://api.openai.com/v1/chat/completions'
  // api: 'v1/chat/completions',
  // servername: 'https://myproxy.com',
  // https://func270519800.azurewebsites.net/api/TranslateTextToEng
  servername: string;
  api: string;
  port: string;
  sessionToken: string;
}
export default function UseDefaultAIAssistAnswerWidget({
  servername,
  api,
  port,
  sessionToken,
}: MessageWidgetProps): AIMessageWidget {
  const [errorMessage, setErrorMessage] = useState<string>('');

  // eslint-disable-next-line @typescript-eslint/no-unused-vars,@typescript-eslint/no-empty-function
  const fileToWidget = (file: File, context: IChatMessage[]): void => {};

  const renderWidget = (): JSX.Element => {
    if (errorMessage && errorMessage.length > 0) {
      const errorsDescriptions:
        | { title: string; action: () => void }[]
        | undefined = [];

      return (
        <ErrorMessageIcon
          errorMessageText={errorMessage}
          errorsDescriptions={errorsDescriptions}
        />
      );
    }

    return <AIWidgetIcon applyZoom color="green" />;
  };

  // async function getData(
  //   textToSend: string,
  //   dialogMessages: ChatCompletionRequestMessage[],
  // ): Promise<string> {
  //   //
  //   const apiEndpoint = 'https://api.openai.com/v1/chat/completions';
  //   const { apiKey } = QBConfig.configAIApi.AIAnswerAssistWidgetConfig; // Замените на ваш реальный ключ API
  //   const model = 'gpt-3.5-turbo';
  //   const requestOptions = {
  //     method: 'POST',
  //     headers: {
  //       'Content-Type': 'application/json',
  //       Authorization: `Bearer ${apiKey}`,
  //     },
  //     body: JSON.stringify({
  //       messages: [...dialogMessages, { role: 'user', content: textToSend }],
  //       model,
  //       temperature: 0.5,
  //     }),
  //   };
  //
  async function getData(
    textToSend: string,
    dialogMessages: IChatMessage[],
  ): Promise<string> {
    let outputMessage = '';
    const apiEndpoint = `${servername}${port}${api}`;
    const apiKey = sessionToken; // Замените на ваш реальный ключ API
    const model = 'gpt-3.5-turbo';
    const prompt = `You are a customer support chat operator. Your goal is to provide helpful and informative responses to customer inquiries. Give a response to the next user's query, considering the entire conversation context, and use grammar and vocabulary at the A2-B2 level. Answer in the format of simple sentences. Do not include question in answer. Please, provide answer for this issue:"${textToSend}"`;
    const requestOptions = {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        Authorization: `Bearer ${apiKey}`,
      },
      body: JSON.stringify({
        messages: [...dialogMessages, { role: 'system', content: prompt }],
        model,
        temperature: 0.5,
      }),
    };

    //
    try {
      const response = await fetch(apiEndpoint, requestOptions);
      const data = await response.json();

      outputMessage = data.choices[0].message?.content || '';
    } catch (err) {
      outputMessage = stringifyError(err);
      setErrorMessage(outputMessage);
    }

    return outputMessage;
  }

  const [textFromWidgetToContent, setTextFromWidgetToContent] = useState('');
  // const textToWidget = (value: string, context: IChatMessage[]): void => {
  //   if (value && value.length > 0) {
  //     // eslint-disable-next-line promise/catch-or-return
  //     getOpenAIApiData(value, context as ChatCompletionRequestMessage[]).then(
  //       // eslint-disable-next-line promise/always-return
  //       (data) => {
  //         setTextFromWidgetToContent(data);
  //       },
  //     );
  //   }
  // };

  const textToWidget = async (
    value: string,
    context: IChatMessage[],
  ): Promise<string> => {
    if (value && value.length > 0) {
      // eslint-disable-next-line no-return-await
      return await getData(value, context).then((data) => {
        setTextFromWidgetToContent(data);

        return data;
      });
    }

    return '';
  };

  return {
    textToContent: textFromWidgetToContent,
    renderWidget,
    textToWidget,
  };
}

==> artan-react-ui-sample-0.0.33.tgz: package/src/Presentation/components/UI/Dialogs/MessagesView/AIWidgets/UseDefaultAIAssistAnswerWidget.tsx <==
import { useState } from 'react';
import { AIMessageWidget } from './AIMessageWidget';
import AIWidgetIcon from '../../../svgs/Icons/AIWidgets/AIWidget';
import ErrorMessageIcon from './ErrorMessageIcon';
import { AISource, IChatMessage } from '../../../../../../Data/source/AISource';

interface MessageWidgetProps {
  // https://api.openai.com/v1/chat/completions'
  // api: 'v1/chat/completions',
  // servername: 'https://myproxy.com',
  // https://func270519800.azurewebsites.net/api/TranslateTextToEng
  servername: string;
  api: string;
  port: string;
  sessionToken: string;
}
export default function UseDefaultAIAssistAnswerWidget({
  servername,
  api,
  port,
  sessionToken,
}: MessageWidgetProps): AIMessageWidget {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const [errorMessage, setErrorMessage] = useState<string>('');

  // eslint-disable-next-line @typescript-eslint/no-unused-vars,@typescript-eslint/no-empty-function
  const fileToWidget = (file: File, context: IChatMessage[]): void => {};

  const renderWidget = (): JSX.Element => {
    if (errorMessage && errorMessage.length > 0) {
      const errorsDescriptions:
        | { title: string; action: () => void }[]
        | undefined = [];

      return (
        <ErrorMessageIcon
          errorMessageText={errorMessage}
          errorsDescriptions={errorsDescriptions}
        />
      );
    }

    return <AIWidgetIcon applyZoom color="green" />;
  };

  // async function getData(
  //   textToSend: string,
  //   dialogMessages: ChatCompletionRequestMessage[],
  // ): Promise<string> {
  //   //
  //   const apiEndpoint = 'https://api.openai.com/v1/chat/completions';
  //   const { apiKey } = QBConfig.configAIApi.AIAnswerAssistWidgetConfig; // Замените на ваш реальный ключ API
  //   const model = 'gpt-3.5-turbo';
  //   const requestOptions = {
  //     method: 'POST',
  //     headers: {
  //       'Content-Type': 'application/json',
  //       Authorization: `Bearer ${apiKey}`,
  //     },
  //     body: JSON.stringify({
  //       messages: [...dialogMessages, { role: 'user', content: textToSend }],
  //       model,
  //       temperature: 0.5,
  //     }),
  //   };
  //
  // async function getData(
  //   prompt: string,
  //   dialogMessages: IChatMessage[],
  // ): Promise<string> {
  //   let outputMessage = '';
  //   const apiEndpoint = `${servername}${port}${api}`;
  //   const apiKey = sessionToken; // Замените на ваш реальный ключ API
  //   const model = 'gpt-3.5-turbo';
  //   const requestOptions = {
  //     method: 'POST',
  //     headers: {
  //       'Content-Type': 'application/json',
  //       Authorization: `Bearer ${apiKey}`,
  //     },
  //     body: JSON.stringify({
  //       messages: [...dialogMessages, { role: 'system', content: prompt }],
  //       model,
  //       temperature: 0.5,
  //     }),
  //   };
  //
  //   //
  //   try {
  //     const response = await fetch(apiEndpoint, requestOptions);
  //     const data = await response.json();
  //
  //     outputMessage = data.choices[0].message?.content || '';
  //   } catch (err) {
  //     outputMessage = stringifyError(err);
  //     setErrorMessage(outputMessage);
  //   }
  //
  //   return outputMessage;
  // }

  const [textFromWidgetToContent, setTextFromWidgetToContent] = useState('');
  // const textToWidget = (value: string, context: IChatMessage[]): void => {
  //   if (value && value.length > 0) {
  //     // eslint-disable-next-line promise/catch-or-return
  //     getOpenAIApiData(value, context as ChatCompletionRequestMessage[]).then(
  //       // eslint-disable-next-line promise/always-return
  //       (data) => {
  //         setTextFromWidgetToContent(data);
  //       },
  //     );
  //   }
  // };

  const textToWidget = async (
    textToSend: string,
    context: IChatMessage[],
  ): Promise<string> => {
    if (textToSend && textToSend.length > 0) {
      const prompt = `You are a customer support chat operator. Your goal is to provide helpful and informative responses to customer inquiries. Give a response to the next user's query, considering the entire conversation context, and use grammar and vocabulary at the A2-B2 level. Answer in the format of simple sentences. Do not include question in answer. Please, provide answer for this issue:"${textToSend}"`;

      // return await getData(prompt, context).then((data) => {
      //   setTextFromWidgetToContent(data);
      //
      //   return data;
      // });
      // eslint-disable-next-line no-return-await
      return await AISource.getData(
        prompt,
        // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
        context,
        servername,
        api,
        port,
        sessionToken,
      ).then((data) => {
        setTextFromWidgetToContent(data);

        return data;
      });
    }

    return '';
  };

  return {
    textToContent: textFromWidgetToContent,
    renderWidget,
    textToWidget,
  };
}
